@@ -16,12 +16,12 @@ from edx_name_affirmation.api import (
     create_verified_name_config,
     get_verified_name,
     get_verified_name_history,
+    is_verified_name_enabled,
     should_use_verified_name_for_certs
 )
 from edx_name_affirmation.exceptions import VerifiedNameMultipleAttemptIds
 from edx_name_affirmation.serializers import VerifiedNameConfigSerializer, VerifiedNameSerializer
 from edx_name_affirmation.statuses import VerifiedNameStatus
-from edx_name_affirmation.toggles import is_verified_name_enabled
 
 
 class AuthenticatedAPIView(APIView):
@@ -32,6 +32,27 @@ class AuthenticatedAPIView(APIView):
     permission_classes = (IsAuthenticated,)
 
 
+class VerifiedNameEnabledView(AuthenticatedAPIView):
+    """
+    Endpoint for the UI to determine if this feature is on
+    /edx_name_affirmation/v1/verified_name_enabled
+
+    Supports:
+        HTTP GET: Returns True or False
+
+    HTTP GET
+        Example response: {
+            "verified_name_enabled": True
+        }
+    """
+    def get(self, request):
+        """
+        Get the state of the verified name enabled flag
+        """
+        flag = {'verified_name_enabled': is_verified_name_enabled()}
+        return Response(flag)
+
+
 class VerifiedNameView(AuthenticatedAPIView):
     """
     Endpoint for a VerifiedName.
